pub async fn run_server(config: ServerConfig) -> Result<()>Expand description
Run the HTTP server with embedded web UI.
This function blocks until the server is shut down (e.g., via Ctrl+C).
pub async fn run_server(config: ServerConfig) -> Result<()>Run the HTTP server with embedded web UI.
This function blocks until the server is shut down (e.g., via Ctrl+C).